@@ -206,7 +206,8 @@ class FingerprintedItem(TestItem):
                 'setup_status': self.setup_status,
                 'execution_status': self.execution_status,
                 'teardown_status': self.teardown_status,
-                'start_time': self.start_time,
+                'start_time': adjusted_timestamp(self.start_time, self.archiver.time_adjust.secs())
+                              if self.start_time else None,
                 'elapsed': self.elapsed_time,
                 'setup_elapsed': self.elapsed_time_setup,
                 'execution_elapsed': self.elapsed_time_execution,
@@ -254,7 +255,8 @@ class TestRun(FingerprintedItem):
         super(TestRun, self).__init__(archiver, '')
         data = {'archived_using': archived_using,
                 'archiver_version': version.ARCHIVER_VERSION,
-                'generated': generated,
+                'generated': adjusted_timestamp(generated, self.archiver.time_adjust.secs())
+                             if generated else None,
                 'generator': generator,
                 'rpa': rpa,
                 'dryrun': dryrun,
@@ -512,7 +514,7 @@ class Archiver:
                 print("PARSING ERROR - printing current stack:")
                 for item in self.stack:
                     print(item.__class__.__name__)
-                raise Exception("Expected to end '{}' but '{}' currently in stack".format(
+                raise Exception("Expected to have '{}' but had '{}' currently in stack".format(
                     expected_type,
                     item.__class__.__name__))
         return item
@@ -720,7 +722,7 @@ def adjusted_timestamp_to_datetime(timestamp, time_adjust_secs=0):
 
 def adjusted_timestamp(timestamp, time_adjust_secs=0):
     adjusted_stamp = timestamp
-    if time_adjust_secs != 0:
+    if timestamp and time_adjust_secs != 0:
         adjusted_datetime = adjusted_timestamp_to_datetime(timestamp, time_adjust_secs)
         adjusted_stamp = adjusted_datetime.isoformat(timespec='milliseconds')
     return adjusted_stamp
